@@ -59,13 +59,13 @@ test_that("Unit tests for PLIV.partialZ invalid score", {
   msg = paste(
     "Callable score not implemented for DoubleMLPLIV with",
     "partialX=FALSE and partialZ=TRUE.")
-  double_mlplr_obj <- DoubleMLPLIV.partialZ(
+  double_mlplr_obj = DoubleMLPLIV.partialZ(
     data_pliv_partialZ$dml_data,
     ml_r = mlr3::lrn("regr.rpart"),
     score = function(x) {
       return(mean(x))
-    })
+    }
+  )
   expect_error(double_mlplr_obj$fit(),
     regexp = msg)
-}
-)
+})
